#!/usr/bin/env python3

"""This script reads the eddy graph from Matlab v6 mat files and
    writes it to a new file in edgelist format.

"""

import scipy.io as sio
import datetime
import csv
import sys

def convert_id(node_index):
    """Convert from node identification in graph to eddy identification in
    shapefiles.

    """
    k = (node_index - 1) // n_max
    date = datetime.date.fromordinal(date_num[k] - 366) - datetime.date(1950,
                                                                        1, 1)
    date = date.days
    eddy_index = node_index - k * n_max
    return date, eddy_index

def print_edgelist(id_child):
    for i1, id_child_1 in enumerate(id_child):
        predecessor = k1 * n_max + 1 + i1
        # id_child_1 may be an int, which means there is a single
        # successor, or id_child_1 may be a numpy array, which means
        # there are several successors.
        
        try:
            # Try processing id_child_1 as an array:
            for node_index in id_child_1:
                writer.writerow(convert_id(predecessor)
                                + convert_id(node_index))
        except TypeError:
            # id_child_1 is a scalar int.
            writer.writerow(convert_id(predecessor) + convert_id(id_child_1))

orientation = sys.argv[1] # "cyclo" or "anti"
id_child = sio.loadmat(f"id_child_{orientation}.mat", squeeze_me=True)\
    ["id_child"]
n_eddies = sio.loadmat(f"N{orientation}.mat", squeeze_me = True)\
    [f"N{orientation}"].astype(int, casting = "safe", copy = False)
date_num = sio.loadmat("date_num.mat", squeeze_me = True)["date_num"]
n_dates = n_eddies.size
print("n_dates =", n_dates)
n_max = id_child.shape[0]
print("n_max =", n_max)

with open(f"edgelist_{orientation}.csv", "w", newline = '') as edgelist:
    writer = csv.writer(edgelist, delimiter = ' ', lineterminator = "\n")
    writer.writerow(["predecessor date subscript", "predecessor eddy subscript",
                     "successor date subscript", "successor eddy subscript"])
    writer.writerow(["k1", "i1", "k2", "i2"])

    for k1 in range(n_dates):
        print_edgelist(id_child[:n_eddies[k1], k1])
